import bpy
import os
from mathutils import Vector

#DEFINE LOCAL VARIABLES
objs = bpy.data.objects
cobjs = bpy.context.scene.objects
mats = bpy.data.materials
texs = bpy.data.textures
imgs = bpy.data.images

path = os.path.dirname(os.path.realpath(__file__))

#env_file_path = path + 'slender.blend'
#bpy.ops.wm.open_mainfile(env_file_path)

#IMPORT SUN DIRECTION
sun_file_path = path + '\slender.sun'
sun_file = open(sun_file_path, 'r')
sun_direction = tuple(map(float, sun_file.read().split(' ')))
sun_file.close()
sun_vector = Vector(sun_direction)

#ROTATE SCENE SUN
sun = bpy.data.objects['Sun']
sun.rotation_mode = 'QUATERNION'
sun.rotation_quaternion = sun_vector.to_track_quat('Z','Y')

#IMPORT COLLADA
model_file_path = path + '\slender.dae'
bpy.ops.wm.collada_import(filepath = model_file_path)

#UNWRAP MESHES TO NEW IMAGES
for obj in objs:
	if obj.type == 'MESH':
		cobjs.active = obj
		msh = obj.data
		name = obj.name
		bpy.ops.mesh.uv_texture_add()
		uv = msh.uv_textures[-1]
		uv.name = name
		faces = uv.data
		img = imgs.new(name + '_img', width = 512, height = 512)
		for face in faces:
			face.image = img
		bpy.ops.object.mode_set(mode = 'EDIT')
		bpy.ops.mesh.select_all()
		bpy.ops.uv.unwrap()
		bpy.ops.object.mode_set(mode = 'OBJECT')
		
#BAKE RENDER		
bpy.ops.object.bake_image()

#MAKE NE MATERIALS
for obj in objs:	
	if obj.type == 'MESH':
		cobjs.active = obj
		msh = obj.data
		name = obj.name
		uv = name
		mat = mats.new(name = name + '_mat')
		slot = mat.texture_slots.add()
		slot.uv_layer = uv
		tex = texs.new(name + '_tex', type = 'IMAGE')
		tex.image = imgs[name + '_img']
		slot.texture = tex
		if not obj.material_slots[0]:
			obj.material_slots.material_slot_add()
		obj.material_slots[0].material=mat

#EXPORT COLLADA
bpy.ops.wm.collada_export(filepath = model_file_path, include_uv_textures = True, include_material_textures = True)

#UPDATE LOG
log = '1'
log_file_path = path + '\slender.log'
log_file = open(log_file_path, 'w')
log_file.write(log)
log_file.close()